@@ -2,7 +2,7 @@ import json
 from dataclasses import dataclass
 
 # create logger
-from bigeye_aws.functions.aws import get_secret
+from bigeye_sdk.functions.aws import get_secret
 from bigeye_sdk.log import get_logger
 
 log = get_logger(__file__)
