@@ -16,7 +16,7 @@ from bigeye_sdk.exceptions.exceptions import NoSourcesFoundException
 from bigeye_sdk.functions.delta_functions import infer_column_mappings, build_ccm, match_tables_by_name
 from bigeye_sdk.functions.metric_functions import set_default_model_type_for_threshold, is_freshness_metric
 from bigeye_sdk.functions.table_functions import get_table_column_priority_first, table_has_metric_time
-from bigeye_sdk.generated.com.torodata.models.generated import MetricCreationState, \
+from bigeye_sdk.generated.com.bigeye.models.generated import MetricCreationState, \
     MetricConfiguration, TimeInterval, Threshold, MetricType, MetricParameter, LookbackType, NotificationChannel, \
     CreateComparisonTableResponse, CreateComparisonTableRequest, \
     ComparisonTableConfiguration, IdAndDisplayName, ComparisonColumnMapping, \
