@@ -14,7 +14,7 @@ from bigeye_sdk.exceptions.exceptions import FileLoadException, BigConfigValidat
 from bigeye_sdk.functions.bigconfig_functions import explode_fq_column_selectors
 from bigeye_sdk.functions.metric_functions import _is_table_level_metric
 from bigeye_sdk.functions.search_and_match_functions import wildcard_search
-from bigeye_sdk.generated.com.torodata.models.generated import Source, CohortDefinition, \
+from bigeye_sdk.generated.com.bigeye.models.generated import Source, CohortDefinition, \
     MetricSuite, CohortAndMetricDefinition, CatalogEntityType, MetricDefinition
 from bigeye_sdk.model.big_config import BigConfig, RowCreationTimes, TagDeployment, TableDeployment
 from bigeye_sdk.model.protobuf_enum_facade import SimplePredefinedMetricName
@@ -97,7 +97,7 @@ class MetricSuiteController:
                      apply=False) -> List[SimpleSLA]:
         """
         Currently operates as an overwrite of existing metrics.  This prevents altering in the front end.  Every time the
-        config is run it will overwrite what is already there.
+        config is run it will overwrite what is already there.  Does not add metrics.
         Args:
             bigconfig: Bigconfig.
 
@@ -502,7 +502,9 @@ class MetricSuiteController:
                                                 unmatched_validations_errors=unmatched_validations_errors,
                                                 fixme_file_list=fixme_file_list)
 
-        deployment_slas = {sla.name: sla for sla in self._upsert_slas(bigconfig, False)}
+        # Creates new SLAs only so that all ids exist when we create the metric suites.
+        deployment_slas = {sla.name: sla for sla in self._upsert_slas(bigconfig=bigconfig, overwrite=False,
+                                                                      apply=False)}
 
         metric_suites = self.bigconfig_to_metric_suites(bigconfig=bigconfig, deployment_slas=deployment_slas)
 
@@ -514,8 +516,9 @@ class MetricSuiteController:
                                                 unmatched_validations_errors=unmatched_validations_errors,
                                                 fixme_file_list=fixme_file_list)
 
+        # Applies changes and overwrites once local validations have passed.
         if apply:
-            self._upsert_slas(bigconfig, True)  # Will always overwrite for Bigconfig.
+            self._upsert_slas(bigconfig=bigconfig, overwrite=True, apply=apply)  # Will always overwrite for Bigconfig.
 
         for metric_suite in metric_suites:
             j = metric_suite.to_json()
