@@ -1,6 +1,6 @@
 from typing import List, Tuple, Dict
 
-from bigeye_sdk.generated.com.torodata.models.generated import Schema
+from bigeye_sdk.generated.com.bigeye.models.generated import Schema
 
 
 def create_schema_id_pairs(source_schema_dict: Dict[str, Schema], target_schema_dict: Dict[str, Schema],
